==> renderbirdcore-0.1.5.tar.gz: renderbirdcore-0.1.5/README.md <==
# RenderBirdCore

![Version](https://img.shields.io/badge/version-0.1.5-blue.svg)

**RenderBirdCore** is an easy-to-use 3D rendering engine for Python based on PyGame and OpenGL. It provides a simple and intuitive interface for creating and rendering 3D objects, managing player's camera, and integrating 2D UI elements, making it ideal for developers looking to easily build simple 3D applications or games with Python.

## Installation

You can install RenderBirdCore via pip:

```bash
pip install RenderBirdCore
```

## Usage

For detailed examples and usage guides, please refer to the [Examples](https://github.com/Wojtekb30/RenderBird-Python-3D-engine/tree/main/Examples) folder on the GitHub repository.

Documentation will also soon be available under [renderbird.birdtech.pl](https://renderbird.birdtech.pl).

Change/update log is available on GitHub in [UpdateLog.md](https://github.com/Wojtekb30/RenderBird-Python-3D-engine/blob/main/UpdateLog.md) file.

## Known Issues

- **Performance with Complex STL Models**: Custom STL 3D models may exhibit poor performance if they are highly complex or have large textures. It is recommended to use low-poly models.

## Future Plans

Future updates for RenderBird will include:

- **Performance Enhancements**: Ongoing optimizations to increase rendering speed and reduce computational overhead.
- **Lighting Support**: Introduction of various lighting options to create more realistic and visually appealing scenes.
- **Additional Features**: Implementation of new functions and tools to expand the engine's capabilities and provide developers with more flexibility.
- **Development software**: I plan to create programs that will make software development with RenderBird even easier.

## Why is it named RenderBirdCore?

I named it RenderBird because I like to add the word Bird to many of my projects. BirdEngine sounded generic so I came up with the name RenderBird. And this package is Core because it is core of the rendering engine, and other functionalities may release as separate packages using this one as the core.

## Community and Feedback

I'm excited to see what you've built with RenderBird! Feel free to share your projects and provide feedback to help improve the engine. Your contributions and ideas are highly appreciated.

==> renderbirdcore-0.1.6.tar.gz: renderbirdcore-0.1.6/README.md <==
# RenderBirdCore

![Version](https://img.shields.io/badge/version-0.1.6-blue.svg)

**RenderBirdCore** is an easy-to-use 3D rendering engine for Python based on PyGame and OpenGL. It provides a simple and intuitive interface for creating and rendering 3D objects, managing player's camera, and integrating 2D UI elements, making it ideal for developers looking to easily build simple 3D applications or games with Python.

## Installation

You can install RenderBirdCore via pip:

```bash
pip install RenderBirdCore
```

## Usage

For detailed examples and usage guides, please refer to the [Examples](https://github.com/Wojtekb30/RenderBird-Python-3D-engine/tree/main/Examples) folder on the GitHub repository.

Full documentation will also soon be available under [renderbird.birdtech.pl](https://renderbird.birdtech.pl).

Change/update log is available on GitHub in [UpdateLog.md](https://github.com/Wojtekb30/RenderBird-Python-3D-engine/blob/main/UpdateLog.md) file.

## Known Issues

- **Performance with Complex STL Models**: Custom STL 3D models may exhibit poor performance if they are highly complex or have large textures. It is recommended to use low-poly models.

## Future Plans

Future updates for RenderBird will include:

- **Performance Enhancements**: Ongoing optimizations to increase rendering speed and reduce computational overhead.
- **Advnaced lighting support**: Currently the engine supports very basic shading which works on legacy OpenGL shading support, but I plan to add methods for more advanced shading and light computing.
- **Additional Features**: Implementation of new functions and tools to expand the engine's capabilities and provide developers with more flexibility.
- **Development software**: I plan to create programs that will make software development with RenderBird even easier.

Note: These updates may come out as separate programs and libraries, so please take a look at my other repositories to see if I released any updates or new functionaliites.

## Why is it named RenderBirdCore?

I named it RenderBird because I like to add the word Bird to many of my projects. BirdEngine sounded generic so I came up with the name RenderBird. And this package is Core because it is core of the rendering engine, and other functionalities may release as separate packages using this one as the core.

## Community and Feedback

I'm excited to see what you've built with RenderBird! Feel free to share your projects and provide feedback to help improve the engine. Your contributions and ideas are highly appreciated.
